#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from dlgBase import DlgBase

import os
import gtk
import vte
import prefs

class DlgOutput(DlgBase) :

    #  === Constructor ===
    def __init__(self, parent) :
        DlgBase.__init__(self, parent, 'dlg-output', ['txtOutput', 'btnClose', 'btnStop'])

        # Connect events
        dic_events = {
            'onBtnStop'   : self.onBtnStop,
            'onDlgResize' : self.onDlgResize,
        }
        self.wTree.signal_autoconnect(dic_events)
        self.cstTerminal.connect("child-exited", self.onChildExited)

        # Restore previous size
        self.dialog.resize(prefs.instance().outputDlgWidth, prefs.instance().outputDlgHeight)        

    # === The subprocess has exited ===
    def onChildExited(self, terminal) :
        self.btnClose.set_sensitive(True)
        self.btnStop.set_sensitive(False)

    # === Creation of custom widgets ===
    def getCustomHandler(self, glade, function_name, widget_name, str1, str2, int1, int2) :
        if function_name == 'createVTE' :
            self.cstTerminal = vte.Terminal()
            self.cstTerminal.show_all()
            return self.cstTerminal

    # === Stop button was clicked ===
    def onBtnStop(self, widget) :
        global cmdPid
        os.kill(cmdPid, 9)
        self.btnClose.set_sensitive(True)
        self.btnStop.set_sensitive(False)

    # === Save the current size ===
    def onDlgResize(self, window, rectangle) :
        prefs.instance().outputDlgWidth  = rectangle.width
        prefs.instance().outputDlgHeight = rectangle.height

    # === Only allow CLOSE signal ===
    def onResponse(self, dialog, response, *args) :
        if response != gtk.RESPONSE_CLOSE :
            self.dialog.stop_emission('response')
        else :
            
            DlgBase.onResponse(self, dialog, response, args)

    # === Display the dialog box and execute the given command line ===
    def show(self, command, args) :
        global cmdPid
        self.btnClose.set_sensitive(False)
        self.btnStop.set_sensitive(True)
        self.dialog.show()
        # Execute the command
        cmdPid = self.cstTerminal.fork_command(command, args)

# === This object is a singleton
dlg = None
def instance(parent) :
    global dlg
    if dlg == None :
        dlg = DlgOutput(parent)
    return dlg
