#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

import sys
import gtk
import prefs
import consts
import msgBox
import os.path
import dlgAbout
import gtk.glade
import dlgOutput

# ---======---
# Main class : create a window to interact with the user
# ---======---
class Main :

    # === Constructor ===
    def __init__(self, argv) :
        # Create the window, retrieve widgets
        self.wTree       = gtk.glade.XML(consts.dirRes + 'win-main.glade')
        self.window      = self.wTree.get_widget('win-main')
        self.filechooser = self.wTree.get_widget('filechooser')
        self.radioRepair = self.wTree.get_widget('radio-repair')
        self.radioVerify = self.wTree.get_widget('radio-verify')
        self.spinMemory  = self.wTree.get_widget('spin-memory')
        self.boxAdvanced = self.wTree.get_widget('box-advanced')
        self.chkAdvanced = self.wTree.get_widget('check-advanced')
        self.btnDefault  = self.wTree.get_widget('btn-default')

        # Connect events
        dic_events = {
            'onWinDestroy'  : self.quit,
            'onBtnQuit'     : self.quit,
            'onMnuQuit'     : self.quit,
            'onMnuAbout'    : self.onMnuAbout,
            'onBtnGo'       : self.onBtnGo,
            'onChkAdvanced' : self.onChkAdvanced,
            'onBtnDefault'  : self.onBtnDefault,
        }
        self.wTree.signal_autoconnect(dic_events)

        # Prepare the file chooser
        self.filechooser.set_current_folder(os.path.expanduser('~'))
        filter = gtk.FileFilter()
        filter.add_pattern('*.par2')
        filter.add_pattern('*.PAR2')
        self.filechooser.set_filter(filter)

        # If a file was given on the command line, select it
        if len(argv) > 1 :
            self.filechooser.set_filename(argv[1])

        # Prepare widgets
        self.prefsToWidgets()

        # Prepare the window and show it
        self.window.set_title(consts.appName)
        self.window.show()
        gtk.main()

    # === Quit ===
    def quit(self, widget) :
        self.widgetsToPrefs()
        prefs.instance().save()
        gtk.main_quit()

    # === Show or hide the advanced frame ===
    def onChkAdvanced(self, widget) :
        if self.chkAdvanced.get_active() :
            self.boxAdvanced.show()
        else :
            self.boxAdvanced.hide()

    # == Display the about dialog box ===
    def onMnuAbout(self, widget) :
        dlgAbout.instance(self.window).show()

    # === Restore default settings ===
    def onBtnDefault(self, widget) :
        self.spinMemory.set_value(consts.dftMaxMemory)

    # === 'Go' button was clicked ===
    def onBtnGo(self, widget) :
        # Ensure that a file has been selected
        if self.filechooser.get_filename() == None :
            msgBox.error(self.window, 'You must first select a par2 file!')
            return
        # Arguments must be stored in a list
        args = ['par2']
        # Check action
        if self.radioRepair.get_active() :
            args += ['r']
        elif self.radioVerify.get_active() :
            args += ['v']
        else :
            msgBox.error(self.window, 'No action selected!')
            return
        # Maximum memory usage
        args += ['-m' + str(int(self.spinMemory.get_value()))]
        args += ['--', self.filechooser.get_filename()]
        # Execute this command
        dlgOutput.instance(self.window).show('par2', args)

    # === Change the state of all widgets, according to the preferences ===
    def prefsToWidgets(self) :
        # Default action when checking files
        if prefs.instance().checkAction == prefs.CHECK_VERIFY :
            self.radioVerify.set_active(True)
        elif prefs.instance().checkAction == prefs.CHECK_REPAIR :
            self.radioRepair.set_active(True)
        # Show advanced options ?
        self.chkAdvanced.set_active(prefs.instance().checkAdvOptions)
        if prefs.instance().checkAdvOptions :
            self.boxAdvanced.show()
        else :
            self.boxAdvanced.hide()
        # Maximum memory usage
        self.spinMemory.set_value(prefs.instance().checkMaxMemory)

    # === Set the preferences, according to the current state of the widgets ===
    def widgetsToPrefs(self) :
        # Default action when checking files
        if self.radioRepair.get_active() :
            prefs.instance().checkAction = prefs.CHECK_REPAIR
        elif self.radioVerify.get_active() :
            prefs.instance().checkAction = prefs.CHECK_VERIFY
        # Show advanced options?
        prefs.instance().checkAdvOptions = self.chkAdvanced.get_active()
        # Maximum memory usage
        prefs.instance().checkMaxMemory = int(self.spinMemory.get_value())


# ---======---
# Entry point
# ---======---
if __name__ != '__main__' :
    print 'Error : Not a module'
    sys.exit()

# Create the main window
Main(sys.argv)
