#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

import os
import consts
import typeToolBox
import xml.dom.ext
import xml.dom.minidom

# Possible action when checking a par2 file
(
    CHECK_VERIFY,
    CHECK_REPAIR,
) = range(2)

# ---======---
# Preferences
# ---======---
class Prefs :

    # === Constructor ===
    def __init__(self) :
        # Give default values to attributes
        self.checkAction     = CHECK_REPAIR
        self.checkMaxMemory  = consts.dftMaxMemory
        self.checkAdvOptions = False
        self.outputDlgHeight = 400
        self.outputDlgWidth  = 500
        # And then load the saved ones
        self.load()

    # === Load the preferences from the disk ===
    def load(self) :
        if os.access(consts.filePrefs, os.F_OK) :
            for elt in xml.dom.minidom.parse(consts.filePrefs).documentElement.getElementsByTagName('pref') :
                name  = elt.getAttribute('name')
                value = typeToolBox.cast(elt.getAttribute('value'), elt.getAttribute('type'))
                self.__dict__[name] = value

    # === Save preferences ===
    def save(self) :
        doc  = xml.dom.minidom.Document()
        root = doc.createElement('prefs')
        doc.appendChild(root)
        # Append each preference to the root
        for pref in self.__dict__.keys() :
            value = self.__dict__[pref]
            node = doc.createElement('pref')
            node.setAttribute('name', pref)
            node.setAttribute('value', str(value))
            node.setAttribute('type', typeToolBox.getType(value))
            root.appendChild(node)
        # Create the file
        file_object = open(consts.filePrefs, "w")
        xml.dom.ext.PrettyPrint(doc, file_object)
        file_object.close()
        

# === This object is a singleton
prefs = None
def instance() :
    global prefs
    if prefs == None :
        prefs = Prefs()
    return prefs
